MethodChannelCicareRtcFlutter constructor
MethodChannelCicareRtcFlutter()
Implementation
MethodChannelCicareRtcFlutter() {
// We don't set the handler here to avoid errors when binary messenger isn't ready
}
MethodChannelCicareRtcFlutter() {
// We don't set the handler here to avoid errors when binary messenger isn't ready
}