CicareRtcFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CicareRtcFlutterPlatform
Implementers

Constructors

CicareRtcFlutterPlatform()
Constructs a CicareRtcFlutterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

incomingCall({required String callerId, String? callerName, String? callerAvatar, required String calleeId, String? calleeName, String? calleeAvatar, required String checkSum, required Map<String, String> metaData}) Future<void>
makeCall({required String callerId, String? callerName, String? callerAvatar, required String calleeId, String? calleeName, String? calleeAvatar, required String checkSum, required Map<String, String> metaData}) Future<void>
makeCallSip({required String callerId, String? callerName, String? callerAvatar, required String destination, String? destinationName, String? destinationAvatar, required String checkSum, required Map<String, String> metaData}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAPI(String baseURL, String apiKey) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CicareRtcFlutterPlatform
The default instance of CicareRtcFlutterPlatform to use.
getter/setter pair