FirebaseMessagingService class
Constructors
- FirebaseMessagingService()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFCMToken(
) → Future< String?> - Get FCM token for device
-
initialize(
) → Future< void> - Initialize Firebase Messaging
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendNotificationToTopic(
{required String topic, required String title, required String body, required Map< String, String> data}) → Future<bool> - Send notification to FCM topic
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited