MethodChannelCicareRtcFlutter class
An implementation of CicareRtcFlutterPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- CicareRtcFlutterPlatform
- MethodChannelCicareRtcFlutter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
incomingCall(
{required String callerId, String? callerName, String? callerAvatar, required String calleeId, String? calleeName, String? calleeAvatar, required String checkSum, required Map< String, String> metaData}) → Future<void> -
override
-
makeCall(
{required String callerId, String? callerName, String? callerAvatar, required String calleeId, String? calleeName, String? calleeAvatar, required String checkSum, required Map< String, String> metaData}) → Future<void> -
override
-
makeCallSip(
{required String callerId, String? callerName, String? callerAvatar, required String destination, String? destinationName, String? destinationAvatar, required String checkSum, required Map< String, String> metaData}) → Future<void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAPI(
String baseURL, String apiKey) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited